@@ -3,21 +3,24 @@ context("test censusxy options functions")
 
 # Test Benchmarks -------------------------------------------------------------
 test_that('Valid Benchmarks are returned', {
+  skip_if_offline()
+
   expect_s3_class(
     cxy_benchmarks(),
     'data.frame'
   )
 })
 
-
 # Test Vintages ---------------------------------------------------------------
 test_that('Valid Vintages are returned', {
+  skip_if_offline()
+
   expect_s3_class(
-    cxy_vintages('Public_AR_Census2010'),
+    cxy_vintages(cxy_benchmarks()$benchmarkName[1]),
     'data.frame'
   )
   expect_s3_class(
-    cxy_vintages(8),
+    cxy_vintages(cxy_benchmarks()$id[1]),
     'data.frame'
   )
 })
@@ -27,6 +30,8 @@ test_that('Invalid Vintages Error Correctly', {
     cxy_vintages(),
     '`benchmark` is a required argument'
   )
+
+  skip_if_offline()
   expect_error(
     cxy_vintages('Bad Input'),
     'Not a Valid Benchmark'
